@@ -1,6 +1,6 @@
 __title__ = 'django-fobi'
-__version__ = '0.4.12'
-__build__ = 0x00001b
+__version__ = '0.4.13'
+__build__ = 0x00001c
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2014-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
