@@ -29,14 +29,18 @@ class EmailPlugin(FormFieldPlugin):
         """
         Get form field instances.
         """
+        widget_attrs = {
+            'class': theme.form_element_html_class,
+            'type': 'email',
+            'placeholder': self.data.placeholder,
+        }
+
         kwargs = {
             'label': self.data.label,
             'help_text': self.data.help_text,
             'initial': self.data.initial,
             'required': self.data.required,
-            'widget': TextInput(
-                attrs={'class': theme.form_element_html_class, 'type': 'email'}
-                ),
+            'widget': TextInput(attrs=widget_attrs),
         }
         if self.data.max_length:
             kwargs['max_length'] = self.data.max_length
