@@ -23,15 +23,20 @@ class DBStoreHandlerPlugin(FormHandlerPlugin):
     uid = UID
     name = _("DB store")
 
-    def run(self, form_entry, request, form):
+    def run(self, form_entry, request, form, form_element_entries=None):
         """
         :param fobi.models.FormEntry form_entry: Instance of
             ``fobi.models.FormEntry``.
         :param django.http.HttpRequest request:
         :param django.forms.Form form:
+        :param iterable form_element_entries: Iterable of
+            ``fobi.models.FormElementEntry`` objects.
         """
         # Clean up the values, leave our content fields and empty values.
-        field_name_to_label_map, cleaned_data = get_processed_form_data(form)
+        field_name_to_label_map, cleaned_data = get_processed_form_data(
+            form,
+            form_element_entries
+            )
 
         for key, value in cleaned_data.items():
             if isinstance(value, (datetime.datetime, datetime.date)):
