@@ -28,11 +28,14 @@ class MailHandlerPlugin(FormHandlerPlugin):
     name = _("Mail")
     form = MailForm
 
-    def run(self, form_entry, request, form):
+    def run(self, form_entry, request, form, form_element_entries=None):
         """
-        :param fobi.models.FormEntry form_entry: Instance of ``fobi.models.FormEntry``.
+        :param fobi.models.FormEntry form_entry: Instance of
+            ``fobi.models.FormEntry``.
         :param django.http.HttpRequest request:
         :param django.forms.Form form:
+        :param iterable form_element_entries: Iterable of
+            ``fobi.models.FormElementEntry`` objects.
         """
         base_url = 'http{secure}://{host}'.format(
             secure = ('s' if request.is_secure() else ''),
@@ -40,7 +43,10 @@ class MailHandlerPlugin(FormHandlerPlugin):
             )
 
         # Clean up the values, leave our content fields and empty values.
-        field_name_to_label_map, cleaned_data = get_processed_form_data(form)
+        field_name_to_label_map, cleaned_data = get_processed_form_data(
+            form,
+            form_element_entries
+            )
 
         rendered_data = []
         for key, value in cleaned_data.items():
@@ -61,7 +67,6 @@ class MailHandlerPlugin(FormHandlerPlugin):
             fail_silently = True
             )
 
-
     def plugin_data_repr(self):
         """
         Human readable representation of plugin data.
